==> vtk6-6.3.0-9-aarch64.pkg.tar.xz: vtk/vtkInteractorStyleRubberBand2D.java <==
// java wrapper for vtkInteractorStyleRubberBand2D object
//

package vtk;
import vtk.*;

public class vtkInteractorStyleRubberBand2D extends vtkInteractorStyle
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void OnLeftButtonDown_2();
  public void OnLeftButtonDown()
    { OnLeftButtonDown_2(); }

  private native void OnLeftButtonUp_3();
  public void OnLeftButtonUp()
    { OnLeftButtonUp_3(); }

  private native void OnMiddleButtonDown_4();
  public void OnMiddleButtonDown()
    { OnMiddleButtonDown_4(); }

  private native void OnMiddleButtonUp_5();
  public void OnMiddleButtonUp()
    { OnMiddleButtonUp_5(); }

  private native void OnRightButtonDown_6();
  public void OnRightButtonDown()
    { OnRightButtonDown_6(); }

  private native void OnRightButtonUp_7();
  public void OnRightButtonUp()
    { OnRightButtonUp_7(); }

  private native void OnMouseMove_8();
  public void OnMouseMove()
    { OnMouseMove_8(); }

  private native void OnMouseWheelForward_9();
  public void OnMouseWheelForward()
    { OnMouseWheelForward_9(); }

  private native void OnMouseWheelBackward_10();
  public void OnMouseWheelBackward()
    { OnMouseWheelBackward_10(); }

  private native void SetRenderOnMouseMove_11(boolean id0);
  public void SetRenderOnMouseMove(boolean id0)
    { SetRenderOnMouseMove_11(id0); }

  private native boolean GetRenderOnMouseMove_12();
  public boolean GetRenderOnMouseMove()
    { return GetRenderOnMouseMove_12(); }

  private native void RenderOnMouseMoveOn_13();
  public void RenderOnMouseMoveOn()
    { RenderOnMouseMoveOn_13(); }

  private native void RenderOnMouseMoveOff_14();
  public void RenderOnMouseMoveOff()
    { RenderOnMouseMoveOff_14(); }

  private native int GetInteraction_15();
  public int GetInteraction()
    { return GetInteraction_15(); }

  private native int[]  GetStartPosition_16();
  public int[]  GetStartPosition()
    { return GetStartPosition_16(); }

  private native int[]  GetEndPosition_17();
  public int[]  GetEndPosition()
    { return GetEndPosition_17(); }

  public vtkInteractorStyleRubberBand2D() { super(); }

  public vtkInteractorStyleRubberBand2D(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-aarch64.pkg.tar.xz: vtk/vtkInteractorStyleRubberBand2D.java <==
// java wrapper for vtkInteractorStyleRubberBand2D object
//

package vtk;
import vtk.*;

public class vtkInteractorStyleRubberBand2D extends vtkInteractorStyle
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void OnLeftButtonDown_2();
  public void OnLeftButtonDown()
    { OnLeftButtonDown_2(); }

  private native void OnLeftButtonUp_3();
  public void OnLeftButtonUp()
    { OnLeftButtonUp_3(); }

  private native void OnMiddleButtonDown_4();
  public void OnMiddleButtonDown()
    { OnMiddleButtonDown_4(); }

  private native void OnMiddleButtonUp_5();
  public void OnMiddleButtonUp()
    { OnMiddleButtonUp_5(); }

  private native void OnRightButtonDown_6();
  public void OnRightButtonDown()
    { OnRightButtonDown_6(); }

  private native void OnRightButtonUp_7();
  public void OnRightButtonUp()
    { OnRightButtonUp_7(); }

  private native void OnMouseMove_8();
  public void OnMouseMove()
    { OnMouseMove_8(); }

  private native void OnMouseWheelForward_9();
  public void OnMouseWheelForward()
    { OnMouseWheelForward_9(); }

  private native void OnMouseWheelBackward_10();
  public void OnMouseWheelBackward()
    { OnMouseWheelBackward_10(); }

  private native void SetRenderOnMouseMove_11(boolean id0);
  public void SetRenderOnMouseMove(boolean id0)
    { SetRenderOnMouseMove_11(id0); }

  private native boolean GetRenderOnMouseMove_12();
  public boolean GetRenderOnMouseMove()
    { return GetRenderOnMouseMove_12(); }

  private native void RenderOnMouseMoveOn_13();
  public void RenderOnMouseMoveOn()
    { RenderOnMouseMoveOn_13(); }

  private native void RenderOnMouseMoveOff_14();
  public void RenderOnMouseMoveOff()
    { RenderOnMouseMoveOff_14(); }

  private native int GetInteraction_15();
  public int GetInteraction()
    { return GetInteraction_15(); }

  private native int[]  GetStartPosition_16();
  public int[]  GetStartPosition()
    { return GetStartPosition_16(); }

  private native int[]  GetEndPosition_17();
  public int[]  GetEndPosition()
    { return GetEndPosition_17(); }

  public vtkInteractorStyleRubberBand2D() { super(); }

  public vtkInteractorStyleRubberBand2D(long id) { super(id); }
  public native long   VTKInit();

}
